@@ -6,14 +6,14 @@
 
 #include "testhelper.h"
 
-#include <applicationcontroller.h>
-#include <locationinformation.h>
-#include <reservationmanager.h>
-#include <tripgroup.h>
-#include <tripgroupmanager.h>
-#include <tripgroupinfoprovider.h>
-#include <weatherforecast.h>
-#include <weatherforecastmanager.h>
+#include "applicationcontroller.h"
+#include "locationinformation.h"
+#include "reservationmanager.h"
+#include "tripgroup.h"
+#include "tripgroupmanager.h"
+#include "tripgroupinfoprovider.h"
+#include "weatherforecast.h"
+#include "weatherforecastmanager.h"
 
 #include <QtTest/qtest.h>
 #include <QSignalSpy>
@@ -41,7 +41,7 @@ private Q_SLOTS:
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
         QCOMPARE(mgr.tripGroups().size(), 1);
 
         TripGroupInfoProvider provider;
