@@ -21,6 +21,8 @@
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
+
 TripGroup::TripGroup() = default;
 
 TripGroup::TripGroup(TripGroupManager *mgr)
@@ -40,15 +42,9 @@ void TripGroup::setName(const QString &name)
     m_name = name;
 }
 
-QVector<QString> TripGroup::elements() const
-{
-    return m_elements;
-}
+QList<QString> TripGroup::elements() const { return m_elements; }
 
-void TripGroup::setElements(const QVector<QString> &elems)
-{
-    m_elements = elems;
-}
+void TripGroup::setElements(const QList<QString> &elems) { m_elements = elems; }
 
 bool TripGroup::load(const QString &path)
 {
@@ -59,8 +55,8 @@ bool TripGroup::load(const QString &path)
     }
 
     const auto obj = JsonIO::read(f.readAll()).toObject();
-    m_name = obj.value(QLatin1String("name")).toString();
-    const auto elems = obj.value(QLatin1String("elements")).toArray();
+    m_name = obj.value("name"_L1).toString();
+    const auto elems = obj.value("elements"_L1).toArray();
     m_elements.clear();
     m_elements.reserve(elems.size());
     for (const auto &v : elems) {
@@ -79,20 +75,39 @@ void TripGroup::store(const QString &path) const
     }
 
     QJsonObject obj;
-    obj.insert(QLatin1String("name"), m_name);
+    obj.insert("name"_L1, m_name);
     QJsonArray elems;
     std::copy(m_elements.begin(), m_elements.end(), std::back_inserter(elems));
-    obj.insert(QLatin1String("elements"), elems);
+    obj.insert("elements"_L1, elems);
     f.write(JsonIO::write(obj));
 }
 
+QString TripGroup::slugName() const
+{
+    QString s;
+    s.reserve(m_name.size());
+    for (const auto c : m_name) {
+        if (c.isLetter() || c.isDigit()) {
+            s.push_back(c.toCaseFolded());
+        } else if (!s.isEmpty() && s.back() != '-'_L1) {
+            s.push_back('-'_L1);
+        }
+    }
+
+    if (s.endsWith('-'_L1)) {
+        s.chop(1);
+    }
+
+    return s;
+}
+
 QDateTime TripGroup::beginDateTime() const
 {
     if (m_elements.empty()) {
         return {};
     }
     const auto res = m_mgr->m_resMgr->reservation(m_elements.at(0));
-    const auto dt = KItinerary::SortUtil::startDateTime(res);
+    auto dt = KItinerary::SortUtil::startDateTime(res);
 
     const auto transfer = m_mgr->m_transferMgr ? m_mgr->m_transferMgr->transfer(m_elements.at(0), Transfer::Before) : Transfer();
     if (transfer.state() == Transfer::Selected && transfer.journey().scheduledDepartureTime().isValid()) {
@@ -107,7 +122,7 @@ QDateTime TripGroup::endDateTime() const
         return {};
     }
     const auto res = m_mgr->m_resMgr->reservation(m_elements.constLast());
-    const auto dt = KItinerary::SortUtil::endDateTime(res);
+    auto dt = KItinerary::SortUtil::endDateTime(res);
 
     const auto transfer = m_mgr->m_transferMgr ? m_mgr->m_transferMgr->transfer(m_elements.constLast(), Transfer::After) : Transfer();
     if (transfer.state() == Transfer::Selected && transfer.journey().scheduledArrivalTime().isValid()) {
